supervisor_action

Function supervisor_action 

pub fn supervisor_action(exit_code: Option<i32>, shutdown: bool) -> Action
Decide whether to restart the worker after it exited with exit_code.

Only exit code worker::EXIT_RESTART (51) restarts, and never once the daemon itself received a shutdown signal.